@@ -19,4 +19,12 @@
  */
 interface Twig_Extension_GlobalsInterface
 {
+    /**
+     * Returns a list of global variables to add to the existing list.
+     *
+     * @return array An array of global variables
+     */
+    public function getGlobals();
 }
+
+class_alias('Twig_Extension_GlobalsInterface', 'Twig\Extension\GlobalsInterface', false);
