@@ -3,14 +3,15 @@
 /*
  * This file is part of Twig.
  *
- * (c) 2010 Fabien Potencier
+ * (c) Fabien Potencier
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
-class Twig_Extension_Optimizer extends Twig_Extension
+
+final class Twig_Extension_Optimizer extends Twig_Extension
 {
-    protected $optimizers;
+    private $optimizers;
 
     public function __construct($optimizers = -1)
     {
@@ -21,9 +22,6 @@ class Twig_Extension_Optimizer extends Twig_Extension
     {
         return array(new Twig_NodeVisitor_Optimizer($this->optimizers));
     }
-
-    public function getName()
-    {
-        return 'optimizer';
-    }
 }
+
+class_alias('Twig_Extension_Optimizer', 'Twig\Extension\OptimizerExtension', false);
