@@ -3,16 +3,16 @@
 /*
  * This file is part of Twig.
  *
- * (c) 2010 Fabien Potencier
+ * (c) Fabien Potencier
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
 class Twig_Node_Expression_Function extends Twig_Node_Expression_Call
 {
-    public function __construct($name, Twig_NodeInterface $arguments, $lineno)
+    public function __construct($name, Twig_Node $arguments, $lineno)
     {
-        parent::__construct(array('arguments' => $arguments), array('name' => $name), $lineno);
+        parent::__construct(array('arguments' => $arguments), array('name' => $name, 'is_defined_test' => false), $lineno);
     }
 
     public function compile(Twig_Compiler $compiler)
@@ -22,17 +22,18 @@ class Twig_Node_Expression_Function extends Twig_Node_Expression_Call
 
         $this->setAttribute('name', $name);
         $this->setAttribute('type', 'function');
-        $this->setAttribute('thing', $function);
         $this->setAttribute('needs_environment', $function->needsEnvironment());
         $this->setAttribute('needs_context', $function->needsContext());
         $this->setAttribute('arguments', $function->getArguments());
-        if ($function instanceof Twig_FunctionCallableInterface || $function instanceof Twig_SimpleFunction) {
-            $this->setAttribute('callable', $function->getCallable());
-        }
-        if ($function instanceof Twig_SimpleFunction) {
-            $this->setAttribute('is_variadic', $function->isVariadic());
+        $callable = $function->getCallable();
+        if ('constant' === $name && $this->getAttribute('is_defined_test')) {
+            $callable = 'twig_constant_is_defined';
         }
+        $this->setAttribute('callable', $callable);
+        $this->setAttribute('is_variadic', $function->isVariadic());
 
         $this->compileCallable($compiler);
     }
 }
+
+class_alias('Twig_Node_Expression_Function', 'Twig\Node\Expression\FunctionExpression', false);
