@@ -3,7 +3,7 @@
 /*
  * This file is part of Twig.
  *
- * (c) 2010 Fabien Potencier
+ * (c) Fabien Potencier
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -16,21 +16,16 @@
  */
 class Twig_Node_Sandbox extends Twig_Node
 {
-    public function __construct(Twig_NodeInterface $body, $lineno, $tag = null)
+    public function __construct(Twig_Node $body, $lineno, $tag = null)
     {
         parent::__construct(array('body' => $body), array(), $lineno, $tag);
     }
 
-    /**
-     * Compiles the node to PHP.
-     *
-     * @param Twig_Compiler $compiler A Twig_Compiler instance
-     */
     public function compile(Twig_Compiler $compiler)
     {
         $compiler
             ->addDebugInfo($this)
-            ->write("\$sandbox = \$this->env->getExtension('sandbox');\n")
+            ->write("\$sandbox = \$this->extensions['Twig_Extension_Sandbox'];\n")
             ->write("if (!\$alreadySandboxed = \$sandbox->isSandboxed()) {\n")
             ->indent()
             ->write("\$sandbox->enableSandbox();\n")
@@ -45,3 +40,5 @@ class Twig_Node_Sandbox extends Twig_Node
         ;
     }
 }
+
+class_alias('Twig_Node_Sandbox', 'Twig\Node\SandboxNode', false);
