@@ -3,7 +3,7 @@
 /*
  * This file is part of Twig.
  *
- * (c) 2011 Fabien Potencier
+ * (c) Fabien Potencier
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -12,15 +12,8 @@
 /**
  * Evaluates an expression, discarding the returned value.
  */
-class Twig_TokenParser_Do extends Twig_TokenParser
+final class Twig_TokenParser_Do extends Twig_TokenParser
 {
-    /**
-     * Parses a token and returns a node.
-     *
-     * @param Twig_Token $token A Twig_Token instance
-     *
-     * @return Twig_NodeInterface A Twig_NodeInterface instance
-     */
     public function parse(Twig_Token $token)
     {
         $expr = $this->parser->getExpressionParser()->parseExpression();
@@ -30,13 +23,10 @@ class Twig_TokenParser_Do extends Twig_TokenParser
         return new Twig_Node_Do($expr, $token->getLine(), $this->getTag());
     }
 
-    /**
-     * Gets the tag name associated with this token parser.
-     *
-     * @return string The tag name
-     */
     public function getTag()
     {
         return 'do';
     }
 }
+
+class_alias('Twig_TokenParser_Do', 'Twig\TokenParser\DoTokenParser', false);
