@@ -3,8 +3,8 @@
 /*
  * This file is part of Twig.
  *
- * (c) 2009 Fabien Potencier
- * (c) 2009 Armin Ronacher
+ * (c) Fabien Potencier
+ * (c) Armin Ronacher
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -17,20 +17,22 @@
  *  {% extends "base.html" %}
  * </pre>
  */
-class Twig_TokenParser_Extends extends Twig_TokenParser
+final class Twig_TokenParser_Extends extends Twig_TokenParser
 {
     public function parse(Twig_Token $token)
     {
+        $stream = $this->parser->getStream();
+
         if (!$this->parser->isMainScope()) {
-            throw new Twig_Error_Syntax('Cannot extend from a block.', $token->getLine(), $this->parser->getFilename());
+            throw new Twig_Error_Syntax('Cannot extend from a block.', $token->getLine(), $stream->getSourceContext());
         }
 
         if (null !== $this->parser->getParent()) {
-            throw new Twig_Error_Syntax('Multiple extends tags are forbidden.', $token->getLine(), $this->parser->getFilename());
+            throw new Twig_Error_Syntax('Multiple extends tags are forbidden.', $token->getLine(), $stream->getSourceContext());
         }
         $this->parser->setParent($this->parser->getExpressionParser()->parseExpression());
 
-        $this->parser->getStream()->expect(Twig_Token::BLOCK_END_TYPE);
+        $stream->expect(Twig_Token::BLOCK_END_TYPE);
     }
 
     public function getTag()
@@ -38,3 +40,5 @@ class Twig_TokenParser_Extends extends Twig_TokenParser
         return 'extends';
     }
 }
+
+class_alias('Twig_TokenParser_Extends', 'Twig\TokenParser\ExtendsTokenParser', false);
