@@ -3,7 +3,7 @@
 /*
  * This file is part of Twig.
  *
- * (c) 2009 Fabien Potencier
+ * (c) Fabien Potencier
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -16,15 +16,8 @@
  *   {% import 'forms.html' as forms %}
  * </pre>
  */
-class Twig_TokenParser_Import extends Twig_TokenParser
+final class Twig_TokenParser_Import extends Twig_TokenParser
 {
-    /**
-     * Parses a token and returns a node.
-     *
-     * @param Twig_Token $token A Twig_Token instance
-     *
-     * @return Twig_NodeInterface A Twig_NodeInterface instance
-     */
     public function parse(Twig_Token $token)
     {
         $macro = $this->parser->getExpressionParser()->parseExpression();
@@ -37,13 +30,10 @@ class Twig_TokenParser_Import extends Twig_TokenParser
         return new Twig_Node_Import($macro, $var, $token->getLine(), $this->getTag());
     }
 
-    /**
-     * Gets the tag name associated with this token parser.
-     *
-     * @return string The tag name
-     */
     public function getTag()
     {
         return 'import';
     }
 }
+
+class_alias('Twig_TokenParser_Import', 'Twig\TokenParser\ImportTokenParser', false);
