@@ -9,9 +9,9 @@
  * file that was distributed with this source code.
  */
 
-require_once dirname(dirname(__FILE__)).'/FilesystemHelper.php';
+require_once dirname(__DIR__).'/FilesystemHelper.php';
 
-class Twig_Tests_Cache_FilesystemTest extends PHPUnit_Framework_TestCase
+class Twig_Tests_Cache_FilesystemTest extends \PHPUnit\Framework\TestCase
 {
     private $classname;
     private $directory;
@@ -65,13 +65,13 @@ class Twig_Tests_Cache_FilesystemTest extends PHPUnit_Framework_TestCase
         $key = $this->directory.'/cache/cachefile.php';
         $content = $this->generateSource();
 
-        $this->assertFalse(file_exists($key));
-        $this->assertFalse(file_exists($this->directory));
+        $this->assertFileNotExists($key);
+        $this->assertFileNotExists($this->directory);
 
         $this->cache->write($key, $content);
 
-        $this->assertTrue(file_exists($this->directory));
-        $this->assertTrue(file_exists($key));
+        $this->assertFileExists($this->directory);
+        $this->assertFileExists($key);
         $this->assertSame(file_get_contents($key), $content);
     }
 
@@ -88,7 +88,7 @@ class Twig_Tests_Cache_FilesystemTest extends PHPUnit_Framework_TestCase
         $key = $this->directory.'/cache/cachefile.php';
         $content = $this->generateSource();
 
-        $this->assertFalse(file_exists($key));
+        $this->assertFileNotExists($key);
 
         // Create read-only root directory.
         @mkdir($this->directory, 0555, true);
@@ -110,12 +110,12 @@ class Twig_Tests_Cache_FilesystemTest extends PHPUnit_Framework_TestCase
         $key = $this->directory.'/cache/cachefile.php';
         $content = $this->generateSource();
 
-        $this->assertFalse(file_exists($key));
+        $this->assertFileNotExists($key);
 
         // Create root directory.
         @mkdir($this->directory, 0777, true);
         // Create read-only subdirectory.
-        @mkdir($this->directory.'/cache' , 0555);
+        @mkdir($this->directory.'/cache', 0555);
         $this->assertTrue(is_dir($this->directory.'/cache'));
 
         $this->cache->write($key, $content);
@@ -130,7 +130,7 @@ class Twig_Tests_Cache_FilesystemTest extends PHPUnit_Framework_TestCase
         $key = $this->directory.'/cache/cachefile.php';
         $content = $this->generateSource();
 
-        $this->assertFalse(file_exists($key));
+        $this->assertFileNotExists($key);
 
         // Create a directory in the place of the cache file.
         @mkdir($key, 0777, true);
