@@ -9,14 +9,10 @@
  * file that was distributed with this source code.
  */
 
-class Twig_Tests_NativeExtensionTest extends PHPUnit_Framework_TestCase
+class Twig_Tests_NativeExtensionTest extends \PHPUnit\Framework\TestCase
 {
     public function testGetProperties()
     {
-        if (defined('HHVM_VERSION')) {
-            $this->markTestSkipped('Skip under HHVM as the behavior is not the same as plain PHP (which is an edge case anyway)');
-        }
-
         $twig = new Twig_Environment(new Twig_Loader_Array(array('index' => '{{ d1.date }}{{ d2.date }}')), array(
             'debug' => true,
             'cache' => false,
