@@ -11,9 +11,6 @@
 
 class Twig_Tests_Node_Expression_Binary_AddTest extends Twig_Test_NodeTestCase
 {
-    /**
-     * @covers Twig_Node_Expression_Binary_Add::__construct
-     */
     public function testConstructor()
     {
         $left = new Twig_Node_Expression_Constant(1, 1);
@@ -24,16 +21,6 @@ class Twig_Tests_Node_Expression_Binary_AddTest extends Twig_Test_NodeTestCase
         $this->assertEquals($right, $node->getNode('right'));
     }
 
-    /**
-     * @covers Twig_Node_Expression_Binary_Add::compile
-     * @covers Twig_Node_Expression_Binary_Add::operator
-     * @dataProvider getTests
-     */
-    public function testCompile($node, $source, $environment = null)
-    {
-        parent::testCompile($node, $source, $environment);
-    }
-
     public function getTests()
     {
         $left = new Twig_Node_Expression_Constant(1, 1);
