@@ -21,14 +21,18 @@ class Twig_Tests_Node_Expression_NameTest extends Twig_Test_NodeTestCase
     public function getTests()
     {
         $node = new Twig_Node_Expression_Name('foo', 1);
+        $self = new Twig_Node_Expression_Name('_self', 1);
         $context = new Twig_Node_Expression_Name('_context', 1);
 
-        $env = new Twig_Environment($this->getMock('Twig_LoaderInterface'), array('strict_variables' => true));
-        $env1 = new Twig_Environment($this->getMock('Twig_LoaderInterface'), array('strict_variables' => false));
+        $env = new Twig_Environment($this->getMockBuilder('Twig_LoaderInterface')->getMock(), array('strict_variables' => true));
+        $env1 = new Twig_Environment($this->getMockBuilder('Twig_LoaderInterface')->getMock(), array('strict_variables' => false));
+
+        $output = '(isset($context["foo"]) || array_key_exists("foo", $context) ? $context["foo"] : (function () { throw new Twig_Error_Runtime(\'Variable "foo" does not exist.\', 1, $this->source); })())';
 
         return array(
-            array($node, "// line 1\n".(PHP_VERSION_ID >= 50400 ? '(isset($context["foo"]) ? $context["foo"] : $this->getContext($context, "foo"))' : '$this->getContext($context, "foo")'), $env),
+            array($node, "// line 1\n".$output, $env),
             array($node, $this->getVariableGetter('foo', 1), $env1),
+            array($self, "// line 1\n\$this->getTemplateName()"),
             array($context, "// line 1\n\$context"),
         );
     }
