@@ -24,7 +24,7 @@ class Twig_Tests_Node_SandboxedPrintTest extends Twig_Test_NodeTestCase
 
         $tests[] = array(new Twig_Node_SandboxedPrint(new Twig_Node_Expression_Constant('foo', 1), 1), <<<EOF
 // line 1
-echo \$this->env->getExtension('sandbox')->ensureToStringAllowed("foo");
+echo \$this->extensions['Twig_Extension_Sandbox']->ensureToStringAllowed("foo");
 EOF
         );
 
